BitBoardDyn

Struct BitBoardDyn 

pub struct BitBoardDyn {
    pub board: BitVec,
    pub n_rows: usize,
    pub n_cols: usize,
}
BitBoard is a 2D array of booleans, stored in the bits of integers. It does assumes that the boundaries are hard, and going past a boundary does not take you back to the other side.

Fields

board: BitVec

The slice of bits that represent the board.

n_rows: usize

How many rows does the board have

n_cols: usize

How many columns does the board have

Implementations

Source

impl BitBoardDyn

pub fn new(n_rows: usize, n_cols: usize) -> Self

Create a new empty board with n_rows and n_cols.