BitBoard

Struct BitBoard 

pub struct BitBoard {
    pub board: BitVec,
    pub n_rows: usize,
    pub n_cols: usize,
}
BitBoard is a 2D array of booleans, stored in the bits of integers. It does assumes that the boundaries are hard, and going past a boundary does not take you back to the other side.

Fields

board: BitVecn_rows: usize

How many rows does the board have

n_cols: usize

How many columns does the board have

Implementations

Source

impl BitBoard

pub fn new(n_rows: usize, n_cols: usize) -> Self

Create a new empty board with n_rows and n_cols.

pub fn index_of(&self, row: usize, col: usize) -> usize

Get the index that we can use to directly access a certain spot on the board

pub fn fill(&mut self, value: bool)

Set all bits to the desired value.

pub fn or(&self, other: &BitBoard) -> Result<BitBoard, DimensionMismatch>

pub fn and(&self, other: &BitBoard) -> Result<BitBoard, DimensionMismatch>

pub fn set(&mut self, row: usize, col: usize, value: bool)

Set the value at index [row, col] to be the new_val.

pub fn set_col(&mut self, col: usize, value: bool)

Set an entire column to a certain value

pub fn set_row(&mut self, row: usize, value: bool)

Set an entire row to a certain value

pub fn set_cardinal_neighbors(&mut self, row: usize, col: usize, value: bool)

Will set the neighbors immediately above, below, left, and right to value. If the neighbor is out of bounds, nothing will happen

pub fn set_diagonals(&mut self, row: usize, col: usize, value: bool)

Set just the spots diagonal from the given position to value. If the neighbor is out of bounds, nothing will happen

pub fn set_all_neighbors(&mut self, row: usize, col: usize, value: bool)

Set the cardinal neighbors and the diagonal neighbors to value. If the neighbor is out of bounds, nothing will happen