pub struct BitBoardDyn {
pub board: BitVec,
pub n_rows: usize,
pub n_cols: usize,
}Expand description
BitBoard is a 2D array of booleans, stored in the bits of integers. It does assumes that the boundaries are hard, and going past a boundary does not take you back to the other side.
Fields
board: BitVecThe slice of bits that represent the board.
n_rows: usizeHow many rows does the board have
n_cols: usizeHow many columns does the board have
Implementations