pub struct BitBoard {
pub board: BitVec,
pub n_rows: usize,
pub n_cols: usize,
}Expand description
BitBoard is a 2D array of booleans, stored in the bits of integers. It does assumes that the boundaries are hard, and going past a boundary does not take you back to the other side.
Fields
board: BitVecn_rows: usizeHow many rows does the board have
n_cols: usizeHow many columns does the board have
Implementations
Sourceimpl BitBoard
impl BitBoard
Sourcepub fn new(n_rows: usize, n_cols: usize) -> Self
pub fn new(n_rows: usize, n_cols: usize) -> Self
Create a new empty board with n_rows and n_cols.
Sourcepub fn index_of(&self, row: usize, col: usize) -> usize
pub fn index_of(&self, row: usize, col: usize) -> usize
Get the index that we can use to directly access a certain spot on the board
pub fn or(&self, other: &BitBoard) -> Result<BitBoard, DimensionMismatch>
pub fn and(&self, other: &BitBoard) -> Result<BitBoard, DimensionMismatch>
Sourcepub fn set(&mut self, row: usize, col: usize, value: bool)
pub fn set(&mut self, row: usize, col: usize, value: bool)
Set the value at index [row, col] to be the new_val.
Sourcepub fn set_cardinal_neighbors(&mut self, row: usize, col: usize, value: bool)
pub fn set_cardinal_neighbors(&mut self, row: usize, col: usize, value: bool)
Will set the neighbors immediately above, below, left, and right to value. If
the neighbor is out of bounds, nothing will happen
Sourcepub fn set_diagonals(&mut self, row: usize, col: usize, value: bool)
pub fn set_diagonals(&mut self, row: usize, col: usize, value: bool)
Set just the spots diagonal from the given position to value. If
the neighbor is out of bounds, nothing will happen
Sourcepub fn set_all_neighbors(&mut self, row: usize, col: usize, value: bool)
pub fn set_all_neighbors(&mut self, row: usize, col: usize, value: bool)
Set the cardinal neighbors and the diagonal neighbors to value. If
the neighbor is out of bounds, nothing will happen